==> haskell-crypto-random-0.0.9-240-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-random
version:              0.0.9
visibility:           public
id:                   crypto-random-0.0.9-Aa2NFm6A81NKt0wPvYJjyR
key:                  crypto-random-0.0.9-Aa2NFm6A81NKt0wPvYJjyR
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-random
synopsis:             Simple cryptographic random related types
description:          Simple cryptographic random related types
category:             Cryptography
abi:                  9962e49b9a77c6fb78afbe83aa5b9622
exposed:              True
exposed-modules:      Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules:
    Crypto.Random.Generator Crypto.Random.Entropy
    Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
    Crypto.Random.Entropy.RDRand

import-dirs:          /usr/lib/ghc-9.0.1/site-local/crypto-random-0.0.9
library-dirs:         /usr/lib/ghc-9.0.1/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/crypto-random-0.0.9
hs-libraries:         HScrypto-random-0.0.9-Aa2NFm6A81NKt0wPvYJjyR
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    securemem-0.1.10-41N9oHXoKmZgzJ7O4ATm5 unix-2.7.2.2
    vector-0.12.3.1-41pb7QyPIvSGm54QlMLBN3

haddock-interfaces:
    /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock

haddock-html:         /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-random-0.0.9-241-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-random
version:              0.0.9
visibility:           public
id:                   crypto-random-0.0.9-9zbeXQMihQ19y41uEMaT7n
key:                  crypto-random-0.0.9-9zbeXQMihQ19y41uEMaT7n
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-random
synopsis:             Simple cryptographic random related types
description:          Simple cryptographic random related types
category:             Cryptography
abi:                  89ca711b44fb3187fc0492d7a22c6819
exposed:              True
exposed-modules:      Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules:
    Crypto.Random.Generator Crypto.Random.Entropy
    Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
    Crypto.Random.Entropy.RDRand

import-dirs:          /usr/lib/ghc-9.0.1/site-local/crypto-random-0.0.9
library-dirs:         /usr/lib/ghc-9.0.1/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/crypto-random-0.0.9
hs-libraries:         HScrypto-random-0.0.9-9zbeXQMihQ19y41uEMaT7n
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    securemem-0.1.10-41N9oHXoKmZgzJ7O4ATm5 unix-2.7.2.2
    vector-0.12.3.1-HMAplmdcuCN6dtD8e6QGwL

haddock-interfaces:
    /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock

haddock-html:         /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
